=========
BioEvents
=========


.. image:: https://img.shields.io/pypi/v/bioevents.svg
        :target: https://pypi.python.org/pypi/bioevents

.. image:: https://readthedocs.org/projects/bioevents/badge/?version=latest
        :target: https://bioevents.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A lightweight library for managing and manipulating time series events,
with a focus on biosensing applications.


* Free software: MIT license
* Documentation: https://bioevents.readthedocs.io.


Features
--------

* Robust tooling for working with time series events.
* A hypnogram class with visualization, manipulation, and characterization functionality

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
